# running-stats


## master
[![Build Status](https://travis-ci.org/kod-kristoff/running-stats-py/g.svg?branch=master)](https://travis-ci.org/kod-kristoff/running-stats-py)
[![codecov](https://codecov.io/gh/kod-kristoff/running-stats-py/g/branch/master/graph/badge.svg)](https://codecov.io/gh/kod-kristoff/running-stats-py)
[![Build](https://github.com/kod-kristoff/running-stats-py/g/workflows/Build/badge.svg)](https://github.com/kod-kristoff/running-stats-py/actions)

